summaryrefslogtreecommitdiff
path: root/src/unexmacosx.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2016-11-06 00:33:43 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2016-11-06 00:42:03 -0700
commitdc152c54f4e44f5f2040883b03f71ff6aa66c893 (patch)
tree7b4f0336a1f03e7a53d980000a42568b10907409 /src/unexmacosx.c
parent84c53436ab25b6c8f76c133e59b34e533ea33cc7 (diff)
downloademacs-dc152c54f4e44f5f2040883b03f71ff6aa66c893.tar.gz
Modernize usage of 'macOS' in doc and comments
Apple changed the spelling of its operating system again, to "macOS", effective with macOS 10.12 Sierra (2016-09-20). Change Emacs documentation and comments to match this. Stick with older OS spellings ("OS X", "Mac OS X") when talking about older releases where the older names are more correct.
Diffstat (limited to 'src/unexmacosx.c')
-rw-r--r--src/unexmacosx.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/unexmacosx.c b/src/unexmacosx.c
index bdacc8b540b..f755f7fafd9 100644
--- a/src/unexmacosx.c
+++ b/src/unexmacosx.c
@@ -1,4 +1,4 @@
/* Dump Emacs in Mach-O format for use on Mac OS X.
Copyright (C) 2001-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -24,7 +24,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Mach-O format: the file loader.h, man pages for Mach-O and ld, old
NEXTSTEP documents of the Mach-O format. The tool otool dumps the
mach header (-h option) and the load commands (-l option) in a
- Mach-O file. The tool nm on Mac OS X displays the symbol table in
+ Mach-O file. The tool nm on macOS displays the symbol table in
a Mach-O file. For examples of unexec for the Mach-O format, see
the file unexnext.c in the GNU Emacs distribution, the file
unexdyld.c in the Darwin port of GNU Emacs 20.7, and unexdyld.c in
@@ -33,7 +33,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Read that to see what they do. This file was written completely
from scratch, making use of information from the above sources. */
/* The Mac OS X implementation of unexec makes use of Darwin's `zone'
memory allocator. All calls to malloc, realloc, and free in Emacs
are redirected to unexec_malloc, unexec_realloc, and unexec_free in
this file. When temacs is run, all memory requests are handled in
@@ -49,7 +49,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
block must be obtained by malloc and the old contents copied to
it. */
-/* Peculiarity of the Mach-O files generated by ld in Mac OS X
+/* Peculiarity of the Mach-O files generated by ld in macOS
(possible causes of future bugs if changed).
The file offset of the start of the __TEXT segment is zero. Since
@@ -118,9 +118,9 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
#include <assert.h>
-/* LC_DATA_IN_CODE is not defined in mach-o/loader.h on OS X 10.7.
+/* LC_DATA_IN_CODE is not defined in mach-o/loader.h on Mac OS X 10.7.
But it is used if we build with "Command Line Tools for Xcode 4.5
- (OS X Lion) - September 2012". */
+ (Mac OS X Lion) - September 2012". */
#ifndef LC_DATA_IN_CODE
#define LC_DATA_IN_CODE 0x29 /* table of non-instructions in __text */
#endif
@@ -1,4 +1,4 @@
-/* Dump Emacs in Mach-O format for use on Mac OS X.
+/* Dump Emacs in Mach-O format for use on macOS.
Copyright (C) 2001-2016 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -33,7 +33,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
Read that to see what they do. This file was written completely
from scratch, making use of information from the above sources. */
-/* The Mac OS X implementation of unexec makes use of Darwin's `zone'
+/* The macOS implementation of unexec makes use of Darwin's `zone'
memory allocator. All calls to malloc, realloc, and free in Emacs
are redirected to unexec_malloc, unexec_realloc, and unexec_free in